@@ -2,7 +2,9 @@ import json
 import requests
 import tornado
 import os
+import threading
 from jupyter_server.base.handlers import APIHandler
+from .utils import update_analytics
 
 AUTOCOMPLETE_ROUTE = "AUTOCOMPLETE"
 
@@ -50,7 +52,11 @@ class AutoCompleteRouteHandler(APIHandler):
 
         if flag:
             autocomplete_data = call_autocomplete(data, api_key, domain)
+            x = threading.Thread(target=update_analytics, args=(domain, api_key, "autocomplete-success"))
+            x.start()
         else:
             autocomplete_data = []
+            x = threading.Thread(target=update_analytics, args=(domain, api_key, "autocomplete-failed"))
+            x.start()
 
         self.finish(json.dumps(autocomplete_data))
