@@ -11,7 +11,7 @@ import subprocess
 from io import BytesIO
 from jupyter_server.base.handlers import APIHandler
 import base64
-
+import tempfile
 
 TRANSFORM_NB_ROUTE = "TRANSFORM_NB"
 
@@ -42,6 +42,7 @@ def call_transform_nb(
     """
     data = create_file_packet(filename)
     data["mode"] = mode
+    data["response_type"] = "FILE"
 
     if instruction:
         data["instruction"] = instruction
@@ -56,8 +57,7 @@ def call_transform_nb(
     )
     return response
 
-
-def threaded_transform(input_data, dirname, uid):
+def threaded_transform(input_data, tmp_name: str):
     nb_filename = input_data["name"]
     instruction = input_data.get("instruction", "")
 
@@ -70,22 +70,9 @@ def threaded_transform(input_data, dirname, uid):
     response = call_transform_nb(nb_filename, api_key, domain, mode, instruction)
     json_response = response.json()
 
-    new_path = os.path.join(dirname, uid)
-    if not os.path.exists(new_path):
-        if os.name is "nt":
-            subprocess.call(["attrib", "+H", new_path])
-        else:
-            os.makedirs(new_path)
-
-    # untar the tar file
-    tar_file_content = base64.b64decode(json_response["tar_file_data"])
-
-    # extract tar without writing to disk
-    tar_file = tarfile.open(fileobj=BytesIO(tar_file_content), mode="r:gz")
-
-    # save and extract to disk
-    tar_file.extractall(path=new_path)
-
+    tar_file_content = base64.b64decode(json_response["file_data"]).decode('utf-8')
+    with open(tmp_name, "w") as f:
+        f.write(tar_file_content)
 
 class TransformJupyterRouteHandler(APIHandler):
     @tornado.web.authenticated
@@ -103,18 +90,14 @@ class TransformJupyterRouteHandler(APIHandler):
         nb_filename = input_data["name"]
 
         # get dirname of nb_filename
-        dirname = os.path.dirname(nb_filename)
-        uid = str(uuid4())
-
-        x = threading.Thread(target=threaded_transform, args=(input_data, dirname, uid))
-        x.start()
-
-        self.finish(
-            json.dumps(
-                {
-                    "message": "processing transformation",
-                    "dirname": str(dirname),
-                    "uid": uid,
-                }
+        with tempfile.NamedTemporaryFile() as tmp:
+            x = threading.Thread(target=threaded_transform, args=(input_data, tmp.name))
+            x.start()
+            self.finish(
+                json.dumps(
+                    {
+                        "message": "processing transformation",
+                        "file_path": tmp.name,
+                    }
+                )
             )
-        )
