@@ -20,4 +20,4 @@ def update_analytics(base_url, api_key, action):
         },
     )
 
-    print("Analytics: ", response)
+    print("Analytics: ", payload, response)
